/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.sensor.cropcircle;

import java.util.List;
import java.util.logging.Logger;
import javax.swing.Icon;
import javax.swing.ImageIcon;
import nl.cloudfarming.client.imp.ImportProcessor;
import nl.cloudfarming.client.sensor.AbstractSensorImportProcessor;
import org.netbeans.api.project.Project;
import org.openide.filesystems.FileObject;
import org.openide.filesystems.FileUtil;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;
import org.openide.util.lookup.ServiceProvider;

/**
 * Processor for cropcircle data
 *
 * @author Timon Veenstra
 */
@ServiceProvider(service = ImportProcessor.class)
@NbBundle.Messages({"sensor cropcircle import error=Failed to import sensor data from file {0}", "sensor import format description=Cropcircle Sensor file (*.csv)"})
public class CropcircleImportProcessor extends AbstractSensorImportProcessor {

    private static final Logger LOGGER = Logger.getLogger(CropcircleImportProcessor.class.getName());
    private static final ImageIcon ICON = ImageUtilities.loadImageIcon(CropCircleDataObject.ICON_BASE, true);

    @Override
    public String[] getSupportedExtentions() {
        return new String[]{"csv", "txt"};
    }

    @Override
    public Icon getIcon() {
        return ICON;
    }

    /**
     * Supports extensions csv and txt
     * @param sensorFile
     * @return 
     */
    @Override
    public boolean isSupported(FileObject sensorFile) {
        // 1: Check extension
        String extLow = sensorFile.getExt().toLowerCase();
        if (! ("csv".equals(extLow) || "txt".equals(extLow))) {
            return false;
        }

        String MIMEType = FileUtil.getMIMEType(sensorFile);
        if (! CropCircleDataObject.MIME_TYPE.equals(MIMEType)){
            return false;
        }
        return true;
    }

    @Override
    public String getFormatDescription() {
        return Bundle.sensor_import_format_description();
    }

    @Override
    public void process(FileObject importFile, Project project) throws IllegalArgumentException {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public <T> void process(FileObject importFile, Project project, List<T> toPopulate) throws IllegalArgumentException {
        throw new UnsupportedOperationException("Not supported yet.");
    }
}
