/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.sensor.cropcircle.view;

import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.ArrayList;
import javax.swing.JComponent;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import nl.cloudfarming.client.logging.AppLogFactory;
import nl.cloudfarming.client.logging.AppLogger;
import nl.cloudfarming.client.sensor.cropcircle.CropcirclePreference;
import org.netbeans.spi.options.OptionsPanelController;
import org.openide.util.HelpCtx;
import org.openide.util.Lookup;

@OptionsPanelController.TopLevelRegistration(categoryName = "#OptionsCategory_Name_Sensormetadata",
iconBase = "nl/cloudfarming/client/sensor/cropcircle/sensor_metadata.png",
keywords = "#OptionsCategory_Keywords_Sensormetadata",
keywordsCategory = "Sensormetadata")
public class CropcircleMetadataController extends OptionsPanelController implements ChangeListener, ItemListener {
    
    private final PropertyChangeSupport pcs = new PropertyChangeSupport(this);
    private boolean changed;
    private static final AppLogger LOG = AppLogFactory.getLogger(CropcircleMetadataController.class);
    private CropcircleMetadataPanel metadataPanel;
   
    @Override
    public void update() {
        load();
        changed = false;
    }

    @Override
    public void applyChanges() {
        store();
        changed = false;
    }

    @Override
    public void cancel() {
        // need not do anything special, if no changes have been persisted yet
    }

    @Override
    public boolean isValid() {
        return valid();
    }

    @Override
    public boolean isChanged() {
        return changed;
    }

    @Override
    public HelpCtx getHelpCtx() {
        return null; // new HelpCtx("...ID") if you have a help set
    }

    @Override
    public JComponent getComponent(Lookup masterLookup) {
        return getPanel();
    }

    @Override
    public void addPropertyChangeListener(PropertyChangeListener l) {
        pcs.addPropertyChangeListener(l);
    }

    @Override
    public void removePropertyChangeListener(PropertyChangeListener l) {
        pcs.removePropertyChangeListener(l);
    }

    public CropcircleMetadataPanel getPanel() {
        if (metadataPanel == null) {
            metadataPanel = new CropcircleMetadataPanel();
        }
        return metadataPanel;
    }

    void changed() {
        if (!changed) {
            changed = true;
            pcs.firePropertyChange(OptionsPanelController.PROP_CHANGED, false, true);
        }
        pcs.firePropertyChange(OptionsPanelController.PROP_VALID, null, null);
    }
    
    public CropcircleMetadataController() {
        init();
    }

    private void init() {
        getPanel().getCropCircleSensorHeightSlider().addChangeListener(this);
        getPanel().getNumberOfSensorCombobox().addItemListener(this);
    }

    void load() {
        getPanel().getDateFormatComboBox().setSelectedItem(CropcirclePreference.SENSOR_DATA_FILE_FORMAT.getValue());
        getPanel().getCropCircleSensorHeightSlider().setValue(Integer.parseInt(CropcirclePreference.CROPCIRCLE_SENSOR_HEIGTH.getValue()));
        getPanel().getNumberOfSensorCombobox().setSelectedItem(Integer.parseInt(CropcirclePreference.NUMBER_OF_CROPCIRCLE_SENSORS.getValue()));
        getPanel().getSensorTypeComboBox().setSelectedItem(CropcirclePreference.SENSOR_TYPE.getValue());
        setSpectralRange(CropcirclePreference.SPECTRAL_CHANNELS.getValue());
        getPanel().getSensorSpreadController().load();
        getPanel().getSensorSpreadController().displaySensorSpreadComponents(Integer.parseInt(CropcirclePreference.NUMBER_OF_CROPCIRCLE_SENSORS.getValue()));
    }

    void store() {
        CropcirclePreference.SENSOR_DATA_FILE_FORMAT.saveValue(getPanel().getDateFormatComboBox().getSelectedItem().toString());
        CropcirclePreference.CROPCIRCLE_SENSOR_HEIGTH.saveValue(((Integer) getPanel().getCropCircleSensorHeightSlider().getValue()).toString());
        CropcirclePreference.NUMBER_OF_CROPCIRCLE_SENSORS.saveValue((getPanel().getNumberOfSensorCombobox().getSelectedItem()).toString());
        CropcirclePreference.SENSOR_TYPE.saveValue(getPanel().getSensorTypeComboBox().getSelectedItem().toString());
        CropcirclePreference.SPECTRAL_CHANNELS.saveValue(getSpectralRange());
        getPanel().getSensorSpreadController().store();
    }

    public boolean valid() {
        ArrayList<javax.swing.JTextField> fields = new ArrayList<javax.swing.JTextField>();
        if (!getPanel().getSensorSpreadController().valid()) {
            return false;
        }
        fields.add(getPanel().getChannelTextField1());
        fields.add(getPanel().getChannelTextField2());
        fields.add(getPanel().getChannelTextField3());
        for (javax.swing.JTextField textField : fields) {
            if (textField.isEnabled()) {
                if (!textField.getText().matches("[0-9]*")) {
                    return false;
                }
            }
        }
        return true;
    }

    public void setSpectralRange(String spectralRange) {
        String[] spreadNumber = spectralRange.split(",");
        if (spreadNumber.length == 3) {
            getPanel().getChannelTextField1().setText(spreadNumber[0]);
            getPanel().getChannelTextField2().setText(spreadNumber[1]);
            getPanel().getChannelTextField3().setText(spreadNumber[2]);
        } else if (spreadNumber.length != 0) {
            StringBuilder logBuilder = new StringBuilder("Error while trying to retreive spectral channel string: ");
            logBuilder.append(spectralRange);
            LOG.error(logBuilder.toString());
        }
    }

    public String getSpectralRange() {
        ArrayList<javax.swing.JTextField> fields = new ArrayList<javax.swing.JTextField>();
        fields.add(getPanel().getChannelTextField1());
        fields.add(getPanel().getChannelTextField2());
        fields.add(getPanel().getChannelTextField3());
        StringBuilder spectralChannels = new StringBuilder();
        for (javax.swing.JTextField textField : fields) {
            if (textField.isEnabled()) {
                spectralChannels.append(textField.getText());
                spectralChannels.append(",");
            }

        }
        //Delete last ','
        spectralChannels.deleteCharAt(spectralChannels.length() - 1);
        return spectralChannels.toString();
    }

    @Override
    public void stateChanged(ChangeEvent e) {
        getPanel().getCropCircleSensorHeightDisplayLabel().setText(((Integer) getPanel().getCropCircleSensorHeightSlider().getValue()).toString());
    }

    @Override
    public void itemStateChanged(ItemEvent e) {
        getPanel().getSensorSpreadController().displaySensorSpreadComponents(Integer.parseInt(getPanel().getNumberOfSensorCombobox().getSelectedItem().toString()));
    }
}
